==> courier-imap-1.3.8.1.tar.gz: courier-imap-1.3.8.1/authlib/preauthvchkpw.c <==
/*
** Copyright 1998 - 2001 Double Precision, Inc.  See COPYING for
** distribution information.
*/

#if	HAVE_CONFIG_H
#include	"config.h"
#endif
#include	<stdio.h>
#include	<stdlib.h>
#include	<string.h>
#include	<errno.h>
#include	<pwd.h>
#if	HAVE_UNISTD_H
#include	<unistd.h>
#endif
#include	"auth.h"
#include	"authmod.h"
#include	<vpopmail.h>
#include	<vauth.h>
#include	"vpopmail_config.h"

extern char *authvchkpw_isvirtual(char *);

extern FILE *authvchkpw_file(const char *, const char *);
extern struct passwd *authvchkpw_search(FILE *, const char *);

static const char rcsid[]="$Id: preauthvchkpw.c,v 1.15 2001/03/26 23:22:44 mrsam Exp $";

int auth_vchkpw_pre(const char *userid, const char *service,
        int (*callback)(struct authinfo *, void *),
                        void *arg)
{
struct passwd *pw;
char	*s;
uid_t	uid;
gid_t	gid;
char	*usercopy;
int	notfound;
struct authinfo auth;

	memset(&auth, 0, sizeof(auth));

	usercopy=strdup(userid);
	if (!usercopy)
	{
		perror("strdup");
		return (1);
	}

	notfound=EACCES;
	if ((s=authvchkpw_isvirtual(usercopy)) != 0)
	{
	char	*t;

		*s++=0;
		while ((t=strchr(s, '/')) != 0)
			*t='.';	/* Fuck you */
	}
	else
	{
		s = DEFAULT_DOMAIN;
		notfound=EPERM;
	}

        vget_assign(s,NULL,0,&uid, &gid);
        pw=vauth_getpw(usercopy, s);
        if ( pw!=NULL ) {
                if (pw->pw_dir == NULL || strlen(pw->pw_dir) == 0 ) {
                        make_user_dir(usercopy, s, uid, gid);
                        pw=vauth_getpw(usercopy, s);
                }
#if HAVE_VLOGAUTH
                vlogauth(pw, s, service);
#endif
        }
        free(usercopy);
        vclose();

	if (!pw)
	{
		errno=notfound;
		return (-1);
	}

	if ( strcmp("webmail", service) == 0 && pw->pw_gid & NO_WEBMAIL ) 
		return(-1);

	if ( strcmp("imap", service) == 0 ) {
		if ( pw->pw_gid & NO_IMAP ) {
			return(-1);
		} else {
#ifdef HAVE_OPEN_SMTP_RELAY
			/* open the relay to imap users */
			open_smtp_relay();
#endif
		}
	}

	pw->pw_uid=uid;
	pw->pw_gid=gid;

	auth.sysuserid= &pw->pw_uid;
	auth.sysgroupid=pw->pw_gid;
	auth.homedir=pw->pw_dir;
	auth.address=userid;
	auth.fullname=pw->pw_gecos;
	auth.passwd=pw->pw_passwd;

	return ((*callback)(&auth, arg));
}

==> courier-imap-1.4.2.tar.gz: courier-imap-1.4.2/authlib/preauthvchkpw.c <==
/*
** Copyright 1998 - 2001 Double Precision, Inc.  See COPYING for
** distribution information.
*/

#if	HAVE_CONFIG_H
#include	"config.h"
#endif
#include	<stdio.h>
#include	<stdlib.h>
#include	<string.h>
#include	<errno.h>
#include	<pwd.h>
#if	HAVE_UNISTD_H
#include	<unistd.h>
#endif
#include	"auth.h"
#include	"authmod.h"
#include	<vpopmail.h>
#include	<vauth.h>
#include	"vpopmail_config.h"

extern char *authvchkpw_isvirtual(char *);

extern FILE *authvchkpw_file(const char *, const char *);

static const char rcsid[]="$Id: preauthvchkpw.c,v 1.16 2001/07/25 21:28:48 mrsam Exp $";

int auth_vchkpw_pre(const char *userid, const char *service,
        int (*callback)(struct authinfo *, void *),
                        void *arg)
{
struct vqpasswd *vpw;
char	*s;
static uid_t uid;
gid_t	gid;
char	*usercopy;
int	notfound;
struct authinfo auth;

	memset(&auth, 0, sizeof(auth));

	usercopy=strdup(userid);
	if (!usercopy)
	{
		perror("strdup");
		return (1);
	}

	notfound=EACCES;
	if ((s=authvchkpw_isvirtual(usercopy)) != 0)
	{
	char	*t;

		*s++=0;
		while ((t=strchr(s, '/')) != 0)
			*t='.';	/* Fuck you */
	}
	else
	{
		s = DEFAULT_DOMAIN;
		notfound=EPERM;
	}

        vget_assign(s,NULL,0,&uid, &gid);
        vpw=vauth_getpw(usercopy, s);
        if ( vpw!=NULL ) {
                if (vpw->pw_dir == NULL || strlen(vpw->pw_dir) == 0 ) {
                        make_user_dir(usercopy, s, uid, gid);
                        vpw=vauth_getpw(usercopy, s);
                }
#ifdef ENABLE_AUTH_LOGGING
                vset_lastauth(usercopy, s, service);
#endif

        }
        free(usercopy);
        vclose();

	if (!vpw)
	{
		errno=notfound;
		return (-1);
	}

	if ( strcmp("webmail", service) == 0 && vpw->pw_gid & NO_WEBMAIL ) 
		return(-1);

	if ( strcmp("imap", service) == 0 ) {
		if ( vpw->pw_gid & NO_IMAP ) {
			return(-1);
		} else {
#ifdef HAVE_OPEN_SMTP_RELAY
			/* open the relay to imap users */
			open_smtp_relay();
#endif
		}
	}

	auth.sysuserid=&uid;
	auth.sysgroupid=gid;
	auth.homedir=vpw->pw_dir;
	auth.address=userid;
	auth.fullname=vpw->pw_gecos;
	auth.passwd=vpw->pw_passwd;

	return ((*callback)(&auth, arg));
}
